# Table of Contents

- [manage-workspace-access](<./manage-workspace-access.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Manage Workspace Access](<./Manage-Workspace-Access.md>)
  - [Overview](<./Manage-Workspace-Access/Overview.md>)
  - [Workspace Access Options](<./Manage-Workspace-Access/Workspace-Access-Options.md>)
  - [Invitation-Based Access for SSO Workspaces](<./Manage-Workspace-Access/Invitation-Based-Access-for-SSO-Workspaces.md>)
  - [Related Resources](<./Manage-Workspace-Access/Related-Resources.md>)
